<?php 

namespace Management\Controllers;

use Management\Services\ManageDashboardService;
use Management\Services\SetFilialSelecionada;
use Zeedhi\Framework\DTO;
use Doctrine\ORM\EntityManager;

class ManageDashboardController {    

    protected $ManageDashboardService, 
              $filialSelecionadaService;

    public function __construct (ManageDashboardService $ManageDashboardService, SetFilialSelecionada $filialSelecionadaService, $environment) {
        $this->ManageDashboardService = $ManageDashboardService;
        $this->filialSelecionadaService = $filialSelecionadaService;
        $this->environment = $environment;
    }
    
    private function returnRequestFilter($request) {
        $arr = array();
        foreach ($request->getFilterCriteria()->getConditions() as $condition) {
            $arr[ $condition['columnName'] ] = $condition['value'];  
        }
        return $arr;
    }
    
    public function getVendasMensais(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->returnRequestFilter($request);
        
        $NRORG = $conditions['NRORG'];
        $CDFILIAL = $conditions['CDFILIAL'];
        
        $retornoTurnos = $this->ManageDashboardService->getVendasMensais($CDFILIAL,$NRORG);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getVendasMensais', $retornoTurnos));
    
    }
    
    public function findObjetivoVendaDiaAlt(DTO\Request\Filter $request, DTO\Response $response){
        $conditions = $this->returnRequestFilter($request);
        
        $NRORG         = $conditions['NRORG'];
        $CDFILIAL      = $conditions['CDFILIAL'];
        $CDOBJANO      = $conditions['CDOBJANO'];
        $NRDIASEMANA   = $conditions['NRDIASEMANA'];
        $DTALT         = $conditions['DTALT'];
        $CDOBJMES      = $conditions['CDOBJMES'];
        
        $retornoTurnos = $this->ManageDashboardService->getObjetivoVendaDiaAlt($CDFILIAL,$NRORG,$CDOBJANO,$NRDIASEMANA,$DTALT,$CDOBJMES);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('objetivoVendaDiaAlt', $retornoTurnos));
    
    }
    
    public function findObjetivoVendaDia(DTO\Request\Filter $request, DTO\Response $response){
        $conditions = $this->returnRequestFilter($request);
        
        $NRORG          = $conditions['NRORG'];
        $CDFILIAL       = $conditions['CDFILIAL'];
        $CDOBJANO       = $conditions['CDOBJANO'];
        $CDOBJDIA       = $conditions['CDOBJDIA'];
        $CDOBJMES       = $conditions['CDOBJMES'];
        
        $retornoTurnos = $this->ManageDashboardService->getObjetivoVendaDia($CDFILIAL,$NRORG,$CDOBJANO,$CDOBJDIA,$CDOBJMES);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('objetivoVendaDia', $retornoTurnos));
    
    }
    
    public function findObjetivoVendaMes(DTO\Request\Filter $request, DTO\Response $response){
        $conditions = $this->returnRequestFilter($request);
        
        $NRORG      =   $conditions['NRORG'];
        $CDFILIAL   =   $conditions['CDFILIAL'];
        $CDOBJANO   =   $conditions['CDOBJANO'];
        $CDOBJMES   =   $conditions['CDOBJMES'];
        
        $retornoTurnos = $this->ManageDashboardService->getObjetivoVendaMes($CDFILIAL,$NRORG,$CDOBJANO,$CDOBJMES);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('objetivoVendaMes', $retornoTurnos));
    
    }
    
    public function getVendasDiarias(DTO\Request\Filter $request, DTO\Response $response){
        $conditions = $this->returnRequestFilter($request);
        
        $NRORG        =   $conditions['NRORG'];
        $CDFILIAL     =   $conditions['CDFILIAL'];
        $DTENTRVENDA  =   $conditions['DTENTRVENDA'];
        
        $retornoTurnos = $this->ManageDashboardService->getVendasDiarias($CDFILIAL,$DTENTRVENDA,$NRORG);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getVendasDiarias', $retornoTurnos));
    }
    
    public function getProdutosMaisVendidos(DTO\Request\Filter $request, DTO\Response $response){
        $conditions = $this->returnRequestFilter($request);
        
        $NRORG          =   $conditions['NRORG'];
        $CDFILIAL       =   $conditions['CDFILIAL'];
        $DTENTRVENDA    =   $conditions['DTENTRVENDA'];
        
        $retornoTurnos = $this->ManageDashboardService->getProdutosMaisVendidos($CDFILIAL,$DTENTRVENDA,$NRORG);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getProdutosMaisVendidos', $retornoTurnos));
    }
    
    public function findDivergenciasConciliacao (DTO\Request\Filter $request, DTO\Response $response) {
        $condition = $this->returnRequestFilter($request);
        
        $NRORG  =   $condition['NRORG'];
        
        $retornoTurnos = $this->ManageDashboardService->findDivergenciasConciliacao($NRORG);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('findDivergenciasConciliacao', $retornoTurnos));
    }
    
    public function setFilialSelecionadaOperador (DTO\Request\Row $request, DTO\Response $response) {
        $condition = $request->getRow();
        
        $CDOPERADOR =   $condition['CDOPERADOR'];
        $NRORG      =   $condition['NRORG'];
            
        $filiais = $this->ManageDashboardService->findFiliaisDoOperador($CDOPERADOR, $NRORG);
        
        $result = array();
        
        if((is_array($filiais) ? count($filiais) : 0) === 1) {
            $CDFILIAL =  $filiais[0]['CDFILIAL'];
            $NMFILIAL =  $filiais[0]['NMFILIAL'];
            
            $condition['CDFILIAL'] = $CDFILIAL;
            
            $this->filialSelecionadaService->changeUserUnit($condition);
            
            $result['IDREDIRECT'] = false;
            $result['CDFILIALSELECIONADA'] = $CDFILIAL;
            $result['NMFILIAL'] = $NMFILIAL;
        } else {
            $result['IDREDIRECT'] = true;
        }
        
        $response->addDataSet( new \Zeedhi\Framework\DataSource\DataSet('filialSelecionada', $result ));
    }
    
    public function findConsolidacaoVendaPendente (DTO\Request\Filter $request, DTO\Response $response) {
        $condition = $this->returnRequestFilter($request);
        
        $CDOPERADOR  =   $condition['CDOPERADOR'];
        $NRORG       =   $condition['NRORG'];
        
        if(array_key_exists('CDFILIAL', $condition)) {
            $CDFILIAL =   $condition['CDFILIAL'];
        } else {
            $CDFILIAL = false;
        }
        
        $retornoTurnos = $this->ManageDashboardService->findConsolidacaoVendaPendente($NRORG, $CDOPERADOR, $CDFILIAL);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getConsolidacaoVendaPendente', $retornoTurnos));
    }
    
    public function findFechamentoCupomPendente (DTO\Request\Filter $request, DTO\Response $response) {
        $condition = $this->returnRequestFilter($request);
        
        $NRORG  =   $condition['NRORG'];
        $CDOPERADOR  =   $condition['CDOPERADOR'];
        
        if(array_key_exists('CDFILIAL', $condition)) {
            $CDFILIAL =   $condition['CDFILIAL'];
        } else {
            $CDFILIAL = false;
        }
        
        $retornoTurnos = $this->ManageDashboardService->findFechamentoCupomPendente($NRORG, $CDOPERADOR, $CDFILIAL);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getFechamentoCupomPendente', $retornoTurnos));
    }
    
    public function findFechamentoCaixaPendente (DTO\Request\Filter $request, DTO\Response $response) {
        $condition = $this->returnRequestFilter($request);
        
        $NRORG  =   $condition['NRORG'];
        $CDOPERADOR  =   $condition['CDOPERADOR'];
        
        if(array_key_exists('CDFILIAL', $condition)) {
            $CDFILIAL =   $condition['CDFILIAL'];
        } else {
            $CDFILIAL = false;
        }
        
        $retornoTurnos = $this->ManageDashboardService->findFechamentoCaixaPendente($NRORG, $CDOPERADOR, $CDFILIAL);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getFechamentoCaixaPendente', $retornoTurnos));
    }
    
    public function checkFilialDisp (DTO\Request\Filter $request, DTO\Response $response) {
        $condition = $this->returnRequestFilter($request);
        $unidadeBloq = $this->ManageDashboardService->unidadeBloq($condition);
        if($unidadeBloq){
            $retorno = $this->ManageDashboardService->perfilUtlBloq($condition);
        } else {
            $retorno = true;
        }
        $UnidadeDisponivel = array($retorno);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('checkFilialDisp', $UnidadeDisponivel));
    }
    
    public function getParamOperador (DTO\Request\Filter $request, DTO\Response $response) {
        $condition = $this->returnRequestFilter($request);
        $paramOperador = $this->ManageDashboardService->paramOperador($condition);
        if((is_array($paramOperador) ? count($paramOperador) : 0) == 0 || $paramOperador == false){
            $paramOperador = array(
                'CDPERFILACESSO' => '',
        	    'NMPERFILACESSO' => '',
        	    'CDOPERADOR' => null);
        }
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('paramOperador', $paramOperador));
    }
    
    public function getParametersAccessControl (DTO\Request\Filter $request, DTO\Response $response) {
        $CDPERFILSELECIONADO =  $this->ManageDashboardService->paramPerfilSelecionado($this->environment->getNrOrg(), $this->environment->getCdOperador());
        $return = array(
            'IDUTLPERFILFILIAL'   => $this->environment->getIdUtlPerfilFilial(),
            'CDPERFILSELECIONADO' => $CDPERFILSELECIONADO['CDPERFILSELECIONADO']);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getParametersAccessControl', $return));
    }
    
    /* Dashboard 2 */
    
    public function findV_QTTICKET (DTO\Request\Filter $request, DTO\Response $response) {
        $condition = $this->returnRequestFilter($request);
        
        $this->setTCDandCDcondition($condition, 'CDFILIAL', 'CDFILIAL');
        
        $NRORG       =   $condition['NRORG'];
        $CDFILIAL    =   $condition['CDFILIAL'];
        $DTVNDCARDS  =   $condition['DTVNDCARDS'];
        $CDOPERADOR  =   $condition['CDOPERADOR'];
        $CHECK  =   isset($condition['CHECK']) ? $condition['CHECK'] : 'S';
        $TCDFILIAL  =   $condition['TCDFILIAL'];
        
        $retornoCards = $this->ManageDashboardService->findV_QTTICKET($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoGraph = $this->ManageDashboardService->findSaleGraph($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoSaleTypeGraph = $this->ManageDashboardService->findSaleTypeGraph($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoSalePaymentGraph = $this->ManageDashboardService->findSalePaymentGraph($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoProdutoMaiorCusto = $this->ManageDashboardService->findProdutoMaiorCusto($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoProdutoMenorCusto = $this->ManageDashboardService->findProdutoMenorCusto($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoProdMaisAjustes = $this->ManageDashboardService->findProdMaisAjustes($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoContasPagar = $this->ManageDashboardService->findContasPagar($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoContasReceber = $this->ManageDashboardService->findContasReceber($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoSaldoEmContas = $this->ManageDashboardService->findSaldoEmContas($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoStatusNota = $this->ManageDashboardService->findStatusNotaTab($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoSemContagem = $TCDFILIAL == 'T' ? $this->ManageDashboardService->findUnidadeSemContagem($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) : $this->ManageDashboardService->findUltimaContagem($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $retornoSaleForDayGraph = $this->ManageDashboardService->findSaleForDayGraph($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        
        
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getCards', $retornoCards));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getGraph', $retornoGraph));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getSaleTypeGraph', $retornoSaleTypeGraph));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getSalePaymentGraph', $retornoSalePaymentGraph));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getSaleForDayGraph', $retornoSaleForDayGraph));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_MAIORCUSTO', $retornoProdutoMaiorCusto));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_MENORCUSTO', $retornoProdutoMenorCusto));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_PRODMAISAJUST', $retornoProdMaisAjustes));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_CONTAGEMPEND', $retornoSemContagem));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_CONTASPAGAR', $retornoContasPagar));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_CONTASRECEBER', $retornoContasReceber));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_SALDOEMCONTAS', $retornoSaldoEmContas));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_STATUSNOTA', $retornoStatusNota));
        
        $retornoCMVTab = $this->ManageDashboardService->findCMVTab($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getT_CMV', $retornoCMVTab));   
    }
    
    private function setTCDandCDcondition(&$condition, $key, $keyName) {
        if( !array_key_exists($key, $condition) || $condition[$keyName] == "" || empty($condition[$keyName]) ) {
            $condition['T'.$keyName] = 'T';    
            $condition[$keyName] = null;    
        } else {
            if(is_array($condition[$key])) {
                    $condition[$keyName] = '_'.implode('_', $condition[$keyName] ).'_';
            }
            $condition['T'.$keyName] = NULL;
            if($key !== $keyName) {
                unset($condition[$keyName]);
            }
        }
    }
}